Preferences
===========

Standard prefereces:

- verbose (bool): enables/disables reporting of (non-exception) warnings and system function

- paramValidation (bool): enables/disables run-time validation of the execute method of a Function object

- reportOutput (bool): enables/disables reporting of execution of execute method

- log (bool): sets LogCondition for a given Component

- functionRunTimeParams (Modulation): uses run-time params to modulate execute method params

[ADDITIONAL DOCUMENTATION COMING...]


.. .. automodule:: psyneulink.core.globals.preferences
   :members:
   :exclude-members: Parameters, PreferenceLevel, PreferenceSetError, PreferenceEntry, PreferenceSetRegistry
